import time

import google.auth.crypt
import google.auth.jwt

from gcloudbearer import SERVICE_ACCOUNT_FILE, SERVICE_ACCOUNT_EMAIL, SERVICE_NAME_AUDIENCE


def main():
    now = int(time.time())

    payload = {
        'iat': now,
        "exp": now + 3600,
        'iss': SERVICE_ACCOUNT_EMAIL,
        'aud': SERVICE_NAME_AUDIENCE,
        'sub': SERVICE_ACCOUNT_EMAIL,
        'email': SERVICE_ACCOUNT_EMAIL
    }

    signer = google.auth.crypt.RSASigner.from_service_account_file(SERVICE_ACCOUNT_FILE)
    jwt = google.auth.jwt.encode(signer, payload)

    return {
        'Authorization': 'Bearer {}'.format(jwt.decode('utf-8')),
        'content-type': 'application/json'
    }


if __name__ == "__main__":
    main()



import os

__version__ = "1.0.0"

SECRET_FOLDER = os.path.dirname(os.path.abspath(__file__) + '/secret')

SERVICE_ACCOUNT_FILE = '/auth.json'.format(SECRET_FOLDER)

GOOGLE_APPLICATION_CREDENTIALS = os.getenv('GOOGLE_APPLICATION_CREDENTIALS', None)
SERVICE_ACCOUNT_EMAIL = os.getenv('SERVICE_ACCOUNT_EMAIL', None)
SERVICE_NAME_AUDIENCE = os.getenv('SERVICE_NAME_AUDIENCE', None)

try:
    with open(SERVICE_ACCOUNT_FILE) as f:
        f.close()
except IOError:
    msg = "auth.json file or secret folder not found"
    raise SystemExit("Error: {}".format(msg))

if not GOOGLE_APPLICATION_CREDENTIALS:
    msg = "environment variable 'GOOGLE_APPLICATION_CREDENTIALS' not found"
    raise SystemExit("KeyError: {}".format(msg))
elif not SERVICE_ACCOUNT_EMAIL:
    msg = "environment variable 'SERVICE_ACCOUNT_EMAIL' not found"
    raise SystemExit("KeyError: {}".format(msg))
elif not SERVICE_NAME_AUDIENCE:
    msg = "environment variable 'SERVICE_NAME_AUDIENCE' not found"
    raise SystemExit("KeyError: {}".format(msg))



import time

import google.auth.crypt
import google.auth.jwt

from gcloudbearer import SERVICE_ACCOUNT_FILE, SERVICE_ACCOUNT_EMAIL, SERVICE_NAME_AUDIENCE


def generate_jwt(sa_keyfile,
                 sa_email,
                 audience,
                 expiry_length=3600):
    now = int(time.time())

    payload = {
        'iat': now,
        "exp": now + expiry_length,
        'iss': sa_email,
        'aud': audience,
        'sub': sa_email,
        'email': sa_email
    }

    signer = google.auth.crypt.RSASigner.from_service_account_file(sa_keyfile)
    jwt = google.auth.jwt.encode(signer, payload)

    return jwt


def generate_headers(
    audience=SERVICE_NAME_AUDIENCE,
    sa_path=SERVICE_ACCOUNT_FILE,
    sa_email=SERVICE_ACCOUNT_EMAIL
):
    expiry_length = 3600
    keyfile_jwt = generate_jwt(sa_path,
                               sa_email,
                               audience,
                               expiry_length)
    return {
        'Authorization': 'Bearer {}'.format(keyfile_jwt.decode('utf-8')),
        'content-type': 'application/json'
    }



"""Setup script for gcloudbearer"""

import os.path
from setuptools import setup

# The directory containing this file
HERE = os.path.abspath(os.path.dirname(__file__))

# The text of the README file
with open(os.path.join(HERE, "README.md")) as fid:
    README = fid.read()

# This call to setup() does all the work
setup(
    name="bearer-gencloud",
    version="1.0.0",
    description="Token generator for cloud endpoints",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/BrunoTSBuzzo/gcloudbearer",
    author="Bruno Buzzo",
    author_email="brunobuzzo.dev@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
    ],
    packages=["gcloudbearer"],
    include_package_data=True,
    install_requires=[
        "google-auth",
    ],
    entry_points={"console_scripts": ["generate_headers=gcloudbearer.__main__:main"]},
)
